@@ -1,9 +1,9 @@
+from typing import MutableMapping
+from requests import Response
 import logging
 import textwrap
 import sys
 import os.path
-from typing import Dict
-from requests import Response
 
 
 class LogManager:
@@ -15,9 +15,11 @@ class LogManager:
         else:
             self.logger.setLevel(logging.ERROR)
 
-        formatter = logging.Formatter('%(asctime)s [%(levelname)s]: %(message)s', '%Y-%m-%d %H:%M:%S')
-        _file_name = os.path.splitext(os.path.basename(sys.argv[0]))[0]
-        file_handler = logging.FileHandler(filename=f"{_file_name}.shiki4py.log", mode='w')
+        formatter = logging.Formatter('%(asctime)s [%(levelname)s]: %(message)s',
+                                      '%Y-%m-%d %H:%M:%S')
+        file_path = os.path.splitext(os.path.split(sys.argv[0])[1])[0]
+        file_handler = logging.FileHandler(filename=f"{file_path}-shiki4py.log",
+                                           mode='w')
         file_handler.setFormatter(formatter)
         self.logger.addHandler(file_handler)
 
@@ -26,7 +28,7 @@ class LogManager:
             console_handler.setFormatter(formatter)
             self.logger.addHandler(console_handler)
 
-    def _formatHeaders(self, d: Dict[str, str]) -> str:
+    def _formatHeaders(self, d: MutableMapping) -> str:
         return '\n'.join(f'{k}: {v}' for k, v in d.items())
 
     def requestError(self, response: Response) -> None:
