@@ -1,13 +1,12 @@
 from shiki4py.store import BaseTokenStore
 from typing import Any, Dict, Optional
 import configparser
-import sys
 import os.path
 
 
-class INITokenStore(BaseTokenStore):
-    def __init__(self) -> None:
-        self._file_path = f"{os.path.splitext(os.path.basename(sys.argv[0]))[0]}.shiki4py.ini"
+class IniTokenStore(BaseTokenStore):
+    def __init__(self, file_path: str = 'tokens') -> None:
+        self._file_path = f"{file_path}-shiki4py.ini"
         self._config = configparser.ConfigParser()
 
         if os.path.isfile(self._file_path):
